package Task::Biodiverse::NoGUI;

use strict;
use warnings;

our $VERSION = '3.001';


1;

__END__

=head1 NAME

Task::Biodiverse::NoGUI - Task to install Biodiverse dependencies for non-GUI use

=head1 SYNOPSIS

  perl -MCPAN -e "install Task::Biodiverse::NoGUI"
  

=head1 DESCRIPTION

Task file for Biodiverse dependencies for non-GUI use across all platforms.

See L<Task::Biodiverse> for the additional libs needed by the GUI.

See L<http://www.purl.org/biodiverse> for more details about Biodiverse itself.  


=head1 AUTHOR

Shawn Laffan

